@@ -4,7 +4,7 @@ LIK.density <- function(pp,hlim=NULL,hseq=NULL,resolution=64,edge=TRUE,auto.opti
                          type=c("fixed","adaptive"),seqres=30,parallelise=NULL,
                          zero.action=0,verbose=TRUE,...){
   
-  if(class(pp)!="ppp") stop("data object 'pp' must be of class \"ppp\"")
+  if(!inherits(pp,"ppp")) stop("data object 'pp' must be of class \"ppp\"")
   W <- Window(pp)
   
   if(is.null(hlim)){
